@@ -1,17 +1,18 @@
 import os
 import warnings
 from abc import abstractmethod
-from typing import Any, Dict, List, Optional, Tuple, Union
+from typing import Any, Dict, Iterable, List, Optional, Tuple, TypeVar, Union
 from uuid import uuid4
 
 import numpy as np
+import pandas as pd
 import pyarrow as pa
 import vaex
 from vaex.dataframe import DataFrame
 
 from dataquality.clients.objectstore import ObjectStore
 from dataquality.core._config import config
-from dataquality.exceptions import GalileoException
+from dataquality.exceptions import GalileoException, GalileoWarning
 from dataquality.loggers.base_logger import BaseGalileoLogger, BaseLoggerAttributes
 from dataquality.schemas.dataframe import BaseLoggerInOutFrames
 from dataquality.schemas.ner import TaggingSchema
@@ -28,6 +29,10 @@ from dataquality.utils.vaex import (
 )
 
 DATA_FOLDERS = ["emb", "prob", "data"]
+DataSet = TypeVar("DataSet", bound=Union[Iterable, pd.DataFrame, DataFrame])
+MetasType = TypeVar("MetasType", bound=Dict[str, List[Union[str, float, int]]])
+MetaType = TypeVar("MetaType", bound=Dict[str, Union[str, float, int]])
+ITER_CHUNK_SIZE = 20_000
 
 
 class BaseGalileoDataLogger(BaseGalileoLogger):
@@ -37,11 +42,35 @@ class BaseGalileoDataLogger(BaseGalileoLogger):
 
     DATA_FOLDER_EXTENSION = {data_folder: "hdf5" for data_folder in DATA_FOLDERS}
 
-    def __init__(
-        self, meta: Optional[Dict[str, List[Union[str, float, int]]]] = None
-    ) -> None:
+    def __init__(self, meta: MetasType = None) -> None:
         super().__init__()
-        self.meta: Dict[str, Any] = meta or {}
+        self.meta: Dict = meta or {}
+        self.log_export_progress = True
+
+    @abstractmethod
+    def log_data_sample(self, *, text: str, id: int, **kwargs: Any) -> None:
+        """Log a single input sample. See child for details"""
+
+    @abstractmethod
+    def log_data_samples(
+        self, *, texts: List[str], ids: List[int], **kwargs: Any
+    ) -> None:
+        """Log a list of input samples. See child for details"""
+
+    @abstractmethod
+    def log_dataset(
+        self,
+        dataset: DataSet,
+        *,
+        text: Union[str, int] = "text",
+        id: Union[str, int] = "id",
+        split: Optional[Split] = None,
+        meta: Optional[List[Union[str, int]]] = None,
+        **kwargs: Any,
+    ) -> None:
+        """Log a dataset/iterable of input samples.
+
+        Provide the dataset and the keys to index into it. See child for details"""
 
     def log(self) -> None:
         """Writes input data to disk in .galileo/logs
@@ -62,7 +91,10 @@ class BaseGalileoDataLogger(BaseGalileoLogger):
         if os.path.isfile(file_path):
             self.append_input_data(df, write_input_dir, file_path)
         else:
-            with vaex.progress.tree("vaex", title="Exporting input data"):
+            if self.log_export_progress:
+                with vaex.progress.tree("vaex", title="Exporting input data"):
+                    df.export(file_path)
+            else:
                 df.export(file_path)
         df.close()
 
@@ -84,7 +116,10 @@ class BaseGalileoDataLogger(BaseGalileoLogger):
             os.rename(tmp_name, file_path)  # Revert name, we aren't logging
             raise e
 
-        with vaex.progress.tree("vaex", title="Appending input data"):
+        if self.log_export_progress:
+            with vaex.progress.tree("vaex", title="Appending input data"):
+                merged_df.export(file_path)
+        else:
             merged_df.export(file_path)
 
         # Cleanup temporary file after appending input data
@@ -110,6 +145,14 @@ class BaseGalileoDataLogger(BaseGalileoLogger):
             split_loc = f"{location}/{split}"
             if not os.path.exists(split_loc):
                 continue
+            if not len(in_frame[in_frame["split"] == split]):
+                warnings.warn(
+                    f"There was output data logged for split {split} but no input data "
+                    "logged. Skipping upload for this split as there are no samples "
+                    "to join to.",
+                    GalileoWarning,
+                )
+                continue
 
             in_frame_split = filter_df(in_frame, "split", split)
             cls.upload_split(object_store, in_frame_split, split, split_loc)
@@ -124,9 +167,10 @@ class BaseGalileoDataLogger(BaseGalileoLogger):
     ) -> None:
         split_runs = os.listdir(split_loc)
 
-        for split_run in split_runs:  # For each inference name or epoch
+        # For each inference name or epoch of the given split
+        for split_run in tqdm(split_runs, total=len(split_runs), desc=split):
             in_frame_slice = in_frame.copy()
-            prob_only = cls.prob_only(split, split_run)
+            prob_only = cls.prob_only(split_runs, split, split_run)
             if split == Split.inference:
                 in_frame_slice = filter_df(in_frame_slice, "inference_name", split_run)
 
@@ -191,6 +235,8 @@ class BaseGalileoDataLogger(BaseGalileoLogger):
         # These df vars will be used in upload_in_out_frames
         emb.set_variable("skip_upload", prob_only)
         data_df.set_variable("skip_upload", prob_only)
+        epoch_inf_val = out_frame[[epoch_or_inf_name]][0][0]
+        prob.set_variable("progress_name", str(epoch_inf_val))
 
         return BaseLoggerInOutFrames(prob=prob, emb=emb, data=data_df)
 
@@ -208,8 +254,12 @@ class BaseGalileoDataLogger(BaseGalileoLogger):
         emb = in_out_frames.emb
         data_df = in_out_frames.data
 
+        epoch_inf = prob.variables.pop("progress_name", "")
+
+        name = "inf_name" if split == Split.inference else "epoch"
+        desc = f"{split} ({name}={epoch_inf})"
         for data_folder, df_obj in tqdm(
-            zip(DATA_FOLDERS, [emb, prob, data_df]), total=3, desc=split
+            zip(DATA_FOLDERS, [emb, prob, data_df]), total=3, desc=desc, leave=False
         ):
             if df_obj.variables.get("skip_upload"):
                 continue
@@ -223,7 +273,9 @@ class BaseGalileoDataLogger(BaseGalileoLogger):
             )
 
     @classmethod
-    def prob_only(cls, split: str, split_run: Union[int, str]) -> bool:
+    def prob_only(
+        cls, split_runs: List[str], split: str, split_run: Union[int, str]
+    ) -> bool:
         if split == Split.inference:
             return False
 
@@ -231,7 +283,11 @@ class BaseGalileoDataLogger(BaseGalileoLogger):
         epoch = int(split_run)
         # For all epochs that aren't the last 2 (early stopping), we only
         # want to upload the probabilities (for DEP calculation).
-        return bool(epoch < cls.logger_config.last_epoch - 1)
+        max_epoch_for_split = max([int(i) for i in split_runs])
+        return bool(epoch < max_epoch_for_split - 1)
+
+    def validate(self) -> None:
+        self.set_split_epoch()
 
     @classmethod
     @abstractmethod
@@ -242,7 +298,8 @@ class BaseGalileoDataLogger(BaseGalileoLogger):
         if len(self.meta.keys()) > self.MAX_META_COLS:
             warnings.warn(
                 f"You can only log up to {self.MAX_META_COLS} metadata attrs. "
-                f"The first {self.MAX_META_COLS} will be logged only."
+                f"The first {self.MAX_META_COLS} will be logged only.",
+                GalileoWarning,
             )
         # When logging metadata columns, if the user breaks a rule, don't fail
         # completely, just warn them and remove that metadata column
@@ -255,7 +312,8 @@ class BaseGalileoDataLogger(BaseGalileoLogger):
                 warnings.warn(
                     f"Metadata column names must not override default values "
                     f"{reserved_keys}. Metadata field {key} "
-                    f"will be removed."
+                    f"will be removed.",
+                    GalileoWarning,
                 )
                 continue
             bad_prefixes = ["galileo", "prob", "gold", "pred"]
@@ -263,14 +321,16 @@ class BaseGalileoDataLogger(BaseGalileoLogger):
                 if key.startswith(bad_start):
                     warnings.warn(
                         "Metadata name must not start with the following "
-                        f"prefixes: (galileo_, prob_, gold_. Won't log {key}"
+                        f"prefixes: (galileo_, prob_, gold_. Won't log {key}",
+                        GalileoWarning,
                     )
                     continue
             # Must be the same length as input
             if len(values) != batch_size:
                 warnings.warn(
                     f"Expected {batch_size} values for key {key} but got "
-                    f"{len(values)}. Will not log this metadata column."
+                    f"{len(values)}. Will not log this metadata column.",
+                    GalileoWarning,
                 )
                 continue
             # Values must be a point, not an iterable
@@ -285,7 +345,8 @@ class BaseGalileoDataLogger(BaseGalileoLogger):
                 warnings.warn(
                     f"Metadata column {key} has one or more invalid values {bad_val} "
                     f"of type {type(bad_val)}. Only strings of "
-                    f"len < {self.MAX_STR_LEN} and numbers can be logged."
+                    f"len < {self.MAX_STR_LEN} and numbers can be logged.",
+                    GalileoWarning,
                 )
                 continue
             valid_meta[key] = values
@@ -313,6 +374,11 @@ class BaseGalileoDataLogger(BaseGalileoLogger):
     ) -> Tuple[DataFrame, DataFrame, DataFrame]:
         ...
 
+    def validate_kwargs(self, kwargs: Dict) -> None:
+        """Raises if a function that shouldn't get kwargs gets any"""
+        if kwargs.keys():
+            raise GalileoException(f"Unexpected arguments: {tuple(kwargs.keys())}")
+
     @abstractmethod
     def _get_input_df(self) -> DataFrame:
         ...
