@@ -17,9 +17,9 @@ class TextMultiLabelModelLogger(TextClassificationModelLogger):
     """
     Class for logging model outputs of Multi Label Text classification models to Galileo
 
-    * emb: (Embeddings) List[List[Union[int,float]]]. Embeddings per text sample input.
-    Only one embedding vector is allowed per input (len(emb) == len(text)
-    and emb.shape==2)
+    * embs: (Embeddings) List[List[Union[int,float]]]. Embeddings per text sample input.
+    Only one embedding vector is allowed per input (len(embs) == len(text)
+    and embs.shape==2)
     * logits: Output from forward pass during model training/evalutation.
     List[List[List[float]]] or List[np.ndarray].
     For each text input, a list of lists of floats is expected (one list/array per task)
@@ -31,6 +31,26 @@ class TextMultiLabelModelLogger(TextClassificationModelLogger):
     * ids: Indexes of each input field: List[int]. These IDs must align with the input
     IDs for each sample input. This will be used to join them together for analysis
     by Galileo.
+
+    ex:
+    .. code-block:: python
+
+        dq.set_epoch(0)
+        dq.set_split("train")
+
+        # 3 samples, embedding dim 768. Only 1 embedding vector can be logged for all
+        # tasks. Each task CANNOT have it's own embedding vector
+        embs: np.ndarray = np.random.rand(3, 768)
+        # Logits per task. In this example, tasks "task_0" and "task_2" have 3 classes
+        # but task "task_1" has 2
+        logits: List[np.ndarray] = [
+            np.random.rand(3, 3),  # 3 samples, 3 classes
+            np.random.rand(3, 3),  # 3 samples, 2 classes
+            np.random.rand(3, 3)  # 3 samples, 3 classes
+        ]
+        ids: List[int] = [0, 1, 2]
+
+        dq.log_model_outputs(embs=embs, logits=logits, ids=ids)
     """
 
     __logger_name__ = "text_multi_label"
@@ -40,27 +60,28 @@ class TextMultiLabelModelLogger(TextClassificationModelLogger):
 
     def __init__(
         self,
-        emb: Union[List, np.ndarray] = None,
+        embs: Union[List, np.ndarray] = None,
         probs: Union[List[List[List]], List[np.ndarray]] = None,
         logits: Union[List[List[List]], List[np.ndarray]] = None,
         ids: Union[List, np.ndarray] = None,
         split: str = "",
         epoch: Optional[int] = None,
+        inference_name: Optional[str] = None,
     ) -> None:
-        super().__init__()
-        # Need to compare to None because they may be np arrays which cannot be
-        # evaluated with bool directly
-        self.emb = emb if emb is not None else []
-        self.probs = probs if probs is not None else []
-        self.logits = logits if logits is not None else []
-        self.ids = ids if ids is not None else []
-        self.split = split
-        self.epoch = epoch
+        super().__init__(
+            embs=embs,
+            probs=probs,
+            logits=logits,
+            ids=ids,
+            split=split,
+            epoch=epoch,
+            inference_name=inference_name,
+        )
 
     def validate(self) -> None:
         """
         Validates that the current config is correct.
-        * emb, probs, and ids must exist and be the same length
+        * embs, probs, and ids must exist and be the same length
         :return:
         """
         super().validate()
@@ -86,7 +107,7 @@ class TextMultiLabelModelLogger(TextClassificationModelLogger):
 
     def _get_data_dict(self) -> Dict[str, Any]:
         data = defaultdict(list)
-        for record_id, prob_per_task, emb in zip(self.ids, self.probs, self.emb):
+        for record_id, prob_per_task, emb in zip(self.ids, self.probs, self.embs):
             # Handle binary classification by making it 2-class classification
             record = {
                 "id": record_id,
