@@ -11,6 +11,7 @@ from dataquality.loggers.model_logger.base_model_logger import BaseGalileoModelL
 from dataquality.schemas import __data_schema_version__
 from dataquality.schemas.ner import NERErrorType, TaggingSchema
 from dataquality.schemas.split import Split
+from dataquality.utils.stdout_logger import get_stdout_logger
 
 
 @unique
@@ -18,7 +19,7 @@ class GalileoModelLoggerAttributes(str, Enum):
     gold_emb = "gold_emb"
     gold_spans = "gold_spans"
     gold_dep = "gold_dep"
-    emb = "emb"
+    embs = "embs"
     pred_emb = "pred_emb"
     pred_spans = "pred_spans"
     pred_dep = "pred_dep"
@@ -41,10 +42,10 @@ class TextNERModelLogger(BaseGalileoModelLogger):
     """
     Class for logging model output data of Text NER models to Galileo.
 
-    * emb: List[np.ndarray]: Each np.ndarray represents all embeddings of a given
+    * embs: List[np.ndarray]: Each np.ndarray represents all embeddings of a given
     sample. These embeddings are from the tokenized text, and will align with the tokens
     in the sample. If you have 12 samples in the dataset, with each sample of 20 tokens
-    in length, and an embedding vector of size 768, len(emb) will be 12, and
+    in length, and an embedding vector of size 768, len(embs) will be 12, and
     np.ndarray.shape is (20, 768).
 
     * logits: List[np.ndarray]: The NER prediction logits from the model
@@ -73,16 +74,16 @@ class TextNERModelLogger(BaseGalileoModelLogger):
             model(the), model(united), model(states), model(on), model(monday)])]
 
         embs =
-            [np.array([embs(the), embs(president), embs(is), embs(joe),
-            embs(bi), embs(##den), embs(<pad>), embs(<pad>), embs(<pad>)]),
-            np.array([embs(joe), embs(bi), embs(##den), embs(addressed),
-            embs(the), embs(united), embs(states), embs(on), embs(monday)])]
+            [np.array([emb(the), emb(president), emb(is), emb(joe),
+            emb(bi), emb(##den), emb(<pad>), emb(<pad>), emb(<pad>)]),
+            np.array([emb(joe), emb(bi), emb(##den), emb(addressed),
+            emb(the), emb(united), emb(states), emb(on), emb(monday)])]
 
         epoch = 0
         ids = [0, 1]  # Must match the data input IDs
         split = "training"
         dataquality.log_model_outputs(
-            emb=emb, logits=logits, ids=ids, split=split, epoch=epoch
+            embs=embs, logits=logits, ids=ids, split=split, epoch=epoch
         )
     """
 
@@ -91,22 +92,27 @@ class TextNERModelLogger(BaseGalileoModelLogger):
 
     def __init__(
         self,
-        emb: List[np.ndarray] = None,
+        embs: List[np.ndarray] = None,
         probs: List[np.ndarray] = None,
         logits: List[np.ndarray] = None,
         ids: Union[List, np.ndarray] = None,
-        split: Optional[str] = None,
+        split: str = "",
         epoch: Optional[int] = None,
+        inference_name: Optional[str] = None,
     ) -> None:
-        super().__init__()
-        # Need to compare to None because they may be np arrays which cannot be
-        # evaluated with bool directly
-        self.emb = emb if emb is not None else []
-        self.probs = probs if probs is not None else []
-        self.logits = logits if logits is not None else []
-        self.ids: Union[List, np.ndarray] = ids if ids is not None else []
-        self.split = split
-        self.epoch = epoch
+        super().__init__(
+            embs=embs,
+            probs=probs,
+            logits=logits,
+            ids=ids,
+            split=split,
+            epoch=epoch,
+            inference_name=inference_name,
+        )
+        # Explicit cast to List from parent
+        self.embs: List[np.ndarray] = list(self.embs)
+        self.logits: List[np.ndarray] = list(self.logits)
+        self.probs: List[np.ndarray] = list(self.probs)
 
         # Calculated internally
         self.gold_emb: List[List[np.ndarray]] = []
@@ -131,34 +137,35 @@ class TextNERModelLogger(BaseGalileoModelLogger):
     def validate(self) -> None:
         """
         Validates that the current config is correct.
-        * emb, probs, and ids must exist and be the same length
+        * embs, probs, and ids must exist and be the same length
         :return:
         """
-        super().validate()
-
+        get_stdout_logger().info(
+            "Validating the output log.", split=self.split, epoch=self.epoch
+        )
         if len(self.logits):
             self.probs = self.convert_logits_to_probs(self.logits).tolist()
         elif len(self.probs):
             warnings.warn("Usage of probs is deprecated, use logits instead")
 
-        emb_len = len(self.emb)
-        prob_len = len(self.probs)
-        id_len = len(self.ids)
+        embs_len = len(self.embs)
+        probs_len = len(self.probs)
+        ids_len = len(self.ids)
 
-        assert all([emb_len, prob_len, id_len]), (
+        assert all([embs_len, probs_len, ids_len]), (
             f"All of emb, probs, and ids for your logger must be set, but "
-            f"got emb:{bool(emb_len)}, probs:{bool(prob_len)}, ids:{bool(id_len)}"
+            f"got emb:{bool(embs_len)}, probs:{bool(probs_len)}, ids:{bool(ids_len)}"
         )
 
-        assert emb_len == prob_len == id_len, (
+        assert embs_len == probs_len == ids_len, (
             f"All of emb, probs, and ids for your logger must be the same "
-            f"length, but got (emb, probs, ids) -> ({emb_len}, {prob_len}, {id_len})"
+            f"length, but got (emb, probs, ids) -> ({embs_len}, {probs_len}, {ids_len})"
         )
 
         # We need to average the embeddings for the tokens within a span
         # so each span has only 1 embedding vector
         logged_sample_ids = []
-        for sample_id, sample_emb, sample_prob in zip(self.ids, self.emb, self.probs):
+        for sample_id, sample_emb, sample_prob in zip(self.ids, self.embs, self.probs):
             # This will return True if there was a prediction or gold span
             if self._process_sample(sample_id, sample_emb, sample_prob):
                 logged_sample_ids.append(sample_id)
@@ -177,6 +184,9 @@ class TextNERModelLogger(BaseGalileoModelLogger):
         A sample should be logged only if there was at least 1 prediction span or 1
         gold span
         """
+        get_stdout_logger().info(
+            "Processing a sample.", split=self.split, epoch=self.epoch
+        )
         # To extract metadata about the sample we are looking at
         sample_key = self.logger_config.get_sample_key(Split(self.split), sample_id)
 
@@ -217,6 +227,9 @@ class TextNERModelLogger(BaseGalileoModelLogger):
         We take the average of the token embeddings per span and use that as the span
         level embedding
         """
+        get_stdout_logger().info(
+            "Extracting span embeddings.", split=self.split, epoch=self.epoch
+        )
         embeddings = []
         for span in spans:
             start = span["start"]
@@ -234,6 +247,9 @@ class TextNERModelLogger(BaseGalileoModelLogger):
         """
         # use length of the tokens stored to strip the pads
         # Drop the spans post first PAD
+        get_stdout_logger().info(
+            "Extracting pred spans.", split=self.split, epoch=self.epoch
+        )
         argmax_indices: List[int] = np.array(pred_prob).argmax(axis=1)
         pred_sequence: List[str] = [
             self.logger_config.labels[x] for x in argmax_indices
@@ -452,6 +468,9 @@ class TextNERModelLogger(BaseGalileoModelLogger):
         gold_sequence = [O, O, O, O, O, B-nothing, I-nothing, I-nothing, O, O] for BIO
         gold_sequence = [O, O, O, O, O, B-nothing, I-nothing, L-nothing, O, O] for BILOU
         """
+        get_stdout_logger().info(
+            "Constructing a gold sequence", split=self.split, epoch=self.epoch
+        )
         gold_sequence = ["O"] * len_sequence
         for span in gold_spans:
             start = span["start"]
@@ -485,6 +504,9 @@ class TextNERModelLogger(BaseGalileoModelLogger):
         dep_scores: DEP scores for every token in a sample, so len(dep_scores) is
             the number of tokens in a sentence
         """
+        get_stdout_logger().info(
+            "Calculating DEP across spans.", split=self.split, epoch=self.epoch
+        )
         dep_score_per_span = []
         for span in spans:
             start = span["start"]
@@ -512,6 +534,7 @@ class TextNERModelLogger(BaseGalileoModelLogger):
             predicted spans which are padded by the model
         :return: The DEP score per-token for both the gold spans and pred spans
         """
+        get_stdout_logger().info("Calculating DEP.", split=self.split, epoch=self.epoch)
         pred_prob = np.array(pred_prob)
         label2idx = {l: i for i, l in enumerate(self.logger_config.labels)}
         argmax_indices: List[int] = pred_prob.argmax(axis=1).tolist()
@@ -556,6 +579,9 @@ class TextNERModelLogger(BaseGalileoModelLogger):
         """
         data: defaultdict = defaultdict(list)
 
+        get_stdout_logger().info(
+            "Getting data dict.", split=self.split, epoch=self.epoch
+        )
         # Loop through samples
         num_samples = len(self.ids)
         for idx in range(num_samples):
@@ -697,6 +723,9 @@ class TextNERModelLogger(BaseGalileoModelLogger):
         In this function, we only look at spans that don't have pred/gold alignment,
         so the error can only be span_shift or missed_label.
         """
+        get_stdout_logger().info(
+            "Getting span error type.", split=self.split, epoch=self.epoch
+        )
         gold_start, gold_end = gold_span
         # We start by assuming missed_label (because it's the worst case)
         # and update if we see overlap
@@ -725,6 +754,9 @@ class TextNERModelLogger(BaseGalileoModelLogger):
         """Converts logits to probs via softmax per sample"""
         # axis ensures that in a matrix of probs with dims num_samples x num_classes
         # we take the softmax for each sample
+        get_stdout_logger().info(
+            "Converting logits to probs.", split=self.split, epoch=self.epoch
+        )
         token_probs = []
         for token_logits in sample_logits:
             token_probs.append(super().convert_logits_to_probs(token_logits))
