@@ -178,8 +178,7 @@ def concat_hdf5_files(location: str, prob_only: bool) -> List[str]:
             str_cols.append(col)
         stores[col] = HDF5Store(f"{location}/{HDF5_STORE}", group, shape, dtype=dtype)
 
-    print("Combining batches for upload")
-    for file in tqdm(files):
+    for file in tqdm(files, leave=False, desc="Combining batches for upload"):
         fname = f"{location}/{file}"
         with h5py.File(fname, "r") as f:
             dset = f["table"]["columns"]
@@ -222,3 +221,11 @@ def filter_df(df: DataFrame, col_name: str, value: str) -> DataFrame:
     df_slice = drop_empty_columns(df_slice)
     # Remove the mask, work with only the filtered rows
     return df_slice.extract()
+
+
+def rename_df(df: DataFrame, columns: Dict) -> DataFrame:
+    """Renames a vaex df using a mapping"""
+    df_copy = df.copy()
+    for old, new in columns.items():
+        df_copy.rename(old, new)
+    return df_copy
